@@ -1,11 +1,11 @@
 #! /usr/bin/env python
+# -*- coding: utf-8 -*-
 
 """
 Library module related with naming convention for the complete rigging toolkit
 """
 
-
-from __future__ import print_function, division, absolute_import, unicode_literals
+from __future__ import print_function, division, absolute_import
 
 import os
 import re
@@ -19,7 +19,9 @@ from collections import OrderedDict
 from tpDcc.libs.nameit.externals import lucidity
 from tpDcc.libs.python import jsonio, yamlio, python, strings as string_utils, name as name_utils
 
-LOGGER = logging.getLogger('tpDcc-libs-nameit')
+from tpDcc.libs.nameit.core import consts
+
+LOGGER = logging.getLogger(consts.LIB_ID)
 
 
 class Serializable(object):
@@ -76,7 +78,7 @@ class Token(Serializable, object):
         :return: bool
         """
 
-        if not isinstance(name, (str, unicode)):
+        if not python.is_string(name):
             return False
 
         if '#' in name or '@' in name:
@@ -157,6 +159,8 @@ class Token(Serializable, object):
         if self.name == 'rule_name':
             return rule.name
 
+        items = self.get_items()
+
         # If we don't pass any name the token will be solved as the default item value
         if name is None:
             if self.is_iterator(self._get_default()):
@@ -164,13 +168,17 @@ class Token(Serializable, object):
             else:
                 return self._get_default()
 
-        if 'iterator' in self.get_items():
-            if name not in self.get_items():
+        if 'iterator' in items:
+            if name not in items:
                 return self._get_default_iterator_value(name, rule=rule)
             else:
                 return name
         else:
-            return self.get_items().get(name)
+            solved_token = items.get(name)
+            if not solved_token and name in list(items.values()):
+                return name
+
+            return solved_token
 
     def _get_default_iterator_value(self, name, rule):
         iterator_format = rule.iterator_format
@@ -214,7 +222,7 @@ class Token(Serializable, object):
             return None
 
         if items and python.is_number(self.default) and self.default >= 0:
-            default_value = self.get_items().values()[self.default - 1]
+            default_value = list(self.get_items().values())[self.default - 1]
             return default_value
 
         return self.default
@@ -235,6 +243,9 @@ class Rule(Serializable, object):
         Return a list of the fields of the rule
         """
 
+        if not self.expression:
+            return list()
+
         return re.findall(r"\{([^}]+)\}", re.sub('_', '_', self.expression))
 
     def iterator_format(self):
@@ -452,19 +463,13 @@ class TemplateToken(Serializable, object):
 class NameLib(object):
 
     DEFAULT_DATA = {
+        'active_rule': '',
         "rules": [],
         "tokens": [],
         "template_tokens": [],
         "templates": []
     }
 
-    _active_rule = ''
-
-    _templates = list()
-    _templates_tokens = list()
-    _tokens = list()
-    _rules = list()
-
     _tokens_key = 'tokens'
     _rules_key = 'rules'
     _keys_key = 'key'
@@ -473,9 +478,18 @@ class NameLib(object):
     _template_tokens_key = 'template_tokens'
 
     def __init__(self, parser_format=None, naming_file=None):
+
+        self._active_rule = ''
+
+        self._templates = list()
+        self._templates_tokens = list()
+        self._tokens = list()
+        self._rules = list()
+
         self._naming_repo_env = 'NAMING_REPO'
         self._parser_format = parser_format or 'yaml'
         self._naming_file = naming_file
+        self.init_naming_data()
 
     @property
     def naming_file(self):
@@ -483,7 +497,10 @@ class NameLib(object):
 
     @naming_file.setter
     def naming_file(self, naming_file_path):
+        if naming_file_path == self._naming_file:
+            return
         self._naming_file = naming_file_path
+        self.init_naming_data()
 
     @property
     def parser_format(self):
@@ -540,6 +557,8 @@ class NameLib(object):
         Sets the current active rule
         """
 
+        if isinstance(name, Rule):
+            name = name.name
         if not self.has_rule(name):
             return False
         self._active_rule = name
@@ -1229,7 +1248,7 @@ class NameLib(object):
         python.clear_list(self._templates_tokens)
 
         if self.has_valid_naming_file():
-            LOGGER.info('Loading session from Naming File: {}'.format(self._naming_file))
+            LOGGER.debug('Loading session from Naming File: {}'.format(self._naming_file))
 
             naming_data = self.load_naming_data()
             if not naming_data:
@@ -1257,11 +1276,13 @@ class NameLib(object):
                     self.load_template_token_from_dict(template_token_data, skip_check=True)
 
         else:
-            repo = repo or self.get_repo()
+            repo = repo or self.get_repo()[0]
+            if not repo:
+                return
             if not os.path.exists(repo):
                 os.mkdir(repo)
 
-            LOGGER.info('Loading session from directory files: {}'.format(repo))
+            LOGGER.debug('Loading session from directory files: {}'.format(repo))
 
             # Tokens and rules
             for dir_path, dir_names, file_names in os.walk(repo):
